summaryrefslogtreecommitdiff
path: root/app/Action
diff options
context:
space:
mode:
Diffstat (limited to 'app/Action')
-rw-r--r--app/Action/Base.php118
-rw-r--r--app/Action/CommentCreation.php17
-rw-r--r--app/Action/CommentCreationMoveTaskColumn.php (renamed from app/Action/TaskLogMoveAnotherColumn.php)15
-rw-r--r--app/Action/TaskAssignCategoryColor.php11
-rw-r--r--app/Action/TaskAssignCategoryLabel.php15
-rw-r--r--app/Action/TaskAssignCategoryLink.php13
-rw-r--r--app/Action/TaskAssignColorCategory.php11
-rw-r--r--app/Action/TaskAssignColorColumn.php11
-rw-r--r--app/Action/TaskAssignColorLink.php11
-rw-r--r--app/Action/TaskAssignColorUser.php11
-rw-r--r--app/Action/TaskAssignCurrentUser.php19
-rw-r--r--app/Action/TaskAssignCurrentUserColumn.php98
-rw-r--r--app/Action/TaskAssignSpecificUser.php11
-rw-r--r--app/Action/TaskAssignUser.php13
-rw-r--r--app/Action/TaskClose.php48
-rw-r--r--app/Action/TaskCloseColumn.php84
-rw-r--r--app/Action/TaskCreation.php11
-rw-r--r--app/Action/TaskDuplicateAnotherProject.php13
-rw-r--r--app/Action/TaskEmail.php11
-rw-r--r--app/Action/TaskMoveAnotherProject.php11
-rw-r--r--app/Action/TaskMoveColumnAssigned.php12
-rw-r--r--app/Action/TaskMoveColumnCategoryChange.php15
-rw-r--r--app/Action/TaskMoveColumnUnAssigned.php12
-rw-r--r--app/Action/TaskOpen.php11
-rw-r--r--app/Action/TaskUpdateStartDate.php11
25 files changed, 517 insertions, 96 deletions
diff --git a/app/Action/CommentCreation.php b/app/Action/CommentCreation.php
index 73fedc3b..d6ea2074 100644
--- a/app/Action/CommentCreation.php
+++ b/app/Action/CommentCreation.php
@@ -15,6 +15,17 @@ use Kanboard\Integration\GitlabWebhook;
class CommentCreation extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Create a comment from an external provider');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
@@ -67,9 +78,9 @@ class CommentCreation extends Base
{
return (bool) $this->comment->create(array(
'reference' => isset($data['reference']) ? $data['reference'] : '',
- 'comment' => empty($data['comment']) ? $data['commit_comment'] : $data['comment'],
+ 'comment' => $data['comment'],
'task_id' => $data['task_id'],
- 'user_id' => empty($data['user_id']) ? 0 : $data['user_id'],
+ 'user_id' => isset($data['user_id']) && $this->projectPermission->isAssignable($this->getProjectId(), $data['user_id']) ? $data['user_id'] : 0,
));
}
@@ -82,6 +93,6 @@ class CommentCreation extends Base
*/
public function hasRequiredCondition(array $data)
{
- return ! empty($data['comment']) || ! empty($data['commit_comment']);
+ return ! empty($data['comment']);
}
}
diff --git a/app/Action/TaskAssignCategoryColor.php b/app/Action/TaskAssignCategoryColor.php
index ffa1ac2a..f5085cb0 100644
--- a/app/Action/TaskAssignCategoryColor.php
+++ b/app/Action/TaskAssignCategoryColor.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskAssignCategoryColor extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Assign automatically a category based on a color');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
diff --git a/app/Action/TaskAssignCategoryLabel.php b/app/Action/TaskAssignCategoryLabel.php
index 0ef474b6..8d291e89 100644
--- a/app/Action/TaskAssignCategoryLabel.php
+++ b/app/Action/TaskAssignCategoryLabel.php
@@ -13,6 +13,17 @@ use Kanboard\Integration\GithubWebhook;
class TaskAssignCategoryLabel extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Change the category based on an external label');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
@@ -64,7 +75,7 @@ class TaskAssignCategoryLabel extends Base
{
$values = array(
'id' => $data['task_id'],
- 'category_id' => isset($data['category_id']) ? $data['category_id'] : $this->getParam('category_id'),
+ 'category_id' => $this->getParam('category_id'),
);
return $this->taskModification->update($values);
@@ -79,6 +90,6 @@ class TaskAssignCategoryLabel extends Base
*/
public function hasRequiredCondition(array $data)
{
- return $data['label'] == $this->getParam('label');
+ return $data['label'] == $this->getParam('label') && empty($data['category_id']);
}
}
diff --git a/app/Action/TaskAssignCategoryLink.php b/app/Action/TaskAssignCategoryLink.php
index 3d00e8d3..b39e41b4 100644
--- a/app/Action/TaskAssignCategoryLink.php
+++ b/app/Action/TaskAssignCategoryLink.php
@@ -14,6 +14,17 @@ use Kanboard\Model\TaskLink;
class TaskAssignCategoryLink extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Assign automatically a category based on a link');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
@@ -65,7 +76,7 @@ class TaskAssignCategoryLink extends Base
{
$values = array(
'id' => $data['task_id'],
- 'category_id' => isset($data['category_id']) ? $data['category_id'] : $this->getParam('category_id'),
+ 'category_id' => $this->getParam('category_id'),
);
return $this->taskModification->update($values);
diff --git a/app/Action/TaskAssignColorCategory.php b/app/Action/TaskAssignColorCategory.php
index a2332f78..3a15b15f 100644
--- a/app/Action/TaskAssignColorCategory.php
+++ b/app/Action/TaskAssignColorCategory.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskAssignColorCategory extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Assign automatically a color based on a category');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
diff --git a/app/Action/TaskAssignColorColumn.php b/app/Action/TaskAssignColorColumn.php
index 53140733..7474045b 100644
--- a/app/Action/TaskAssignColorColumn.php
+++ b/app/Action/TaskAssignColorColumn.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskAssignColorColumn extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Assign a color when the task is moved to a specific column');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
diff --git a/app/Action/TaskAssignColorLink.php b/app/Action/TaskAssignColorLink.php
index 67b2ef62..f71df70e 100644
--- a/app/Action/TaskAssignColorLink.php
+++ b/app/Action/TaskAssignColorLink.php
@@ -13,6 +13,17 @@ use Kanboard\Model\TaskLink;
class TaskAssignColorLink extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Change task color when using a specific task link');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
diff --git a/app/Action/TaskAssignColorUser.php b/app/Action/TaskAssignColorUser.php
index 6bf02c36..6e56bdc5 100644
--- a/app/Action/TaskAssignColorUser.php
+++ b/app/Action/TaskAssignColorUser.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskAssignColorUser extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Assign a color to a specific user');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
diff --git a/app/Action/TaskAssignCurrentUser.php b/app/Action/TaskAssignCurrentUser.php
index f34c4f36..192a120c 100644
--- a/app/Action/TaskAssignCurrentUser.php
+++ b/app/Action/TaskAssignCurrentUser.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskAssignCurrentUser extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Assign the task to the person who does the action');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
@@ -22,7 +33,6 @@ class TaskAssignCurrentUser extends Base
{
return array(
Task::EVENT_CREATE,
- Task::EVENT_MOVE_COLUMN,
);
}
@@ -34,9 +44,7 @@ class TaskAssignCurrentUser extends Base
*/
public function getActionRequiredParameters()
{
- return array(
- 'column_id' => t('Column'),
- );
+ return array();
}
/**
@@ -49,7 +57,6 @@ class TaskAssignCurrentUser extends Base
{
return array(
'task_id',
- 'column_id',
);
}
@@ -83,6 +90,6 @@ class TaskAssignCurrentUser extends Base
*/
public function hasRequiredCondition(array $data)
{
- return $data['column_id'] == $this->getParam('column_id');
+ return true;
}
}
diff --git a/app/Action/TaskAssignCurrentUserColumn.php b/app/Action/TaskAssignCurrentUserColumn.php
new file mode 100644
index 00000000..05d08dd3
--- /dev/null
+++ b/app/Action/TaskAssignCurrentUserColumn.php
@@ -0,0 +1,98 @@
+<?php
+
+namespace Kanboard\Action;
+
+use Kanboard\Model\Task;
+
+/**
+ * Assign a task to the logged user on column change
+ *
+ * @package action
+ * @author Frederic Guillot
+ */
+class TaskAssignCurrentUserColumn extends Base
+{
+ /**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Assign the task to the person who does the action when the column is changed');
+ }
+
+ /**
+ * Get the list of compatible events
+ *
+ * @access public
+ * @return array
+ */
+ public function getCompatibleEvents()
+ {
+ return array(
+ Task::EVENT_MOVE_COLUMN,
+ );
+ }
+
+ /**
+ * Get the required parameter for the action (defined by the user)
+ *
+ * @access public
+ * @return array
+ */
+ public function getActionRequiredParameters()
+ {
+ return array(
+ 'column_id' => t('Column'),
+ );
+ }
+
+ /**
+ * Get the required parameter for the event
+ *
+ * @access public
+ * @return string[]
+ */
+ public function getEventRequiredParameters()
+ {
+ return array(
+ 'task_id',
+ 'column_id',
+ );
+ }
+
+ /**
+ * Execute the action
+ *
+ * @access public
+ * @param array $data Event data dictionary
+ * @return bool True if the action was executed or false when not executed
+ */
+ public function doAction(array $data)
+ {
+ if (! $this->userSession->isLogged()) {
+ return false;
+ }
+
+ $values = array(
+ 'id' => $data['task_id'],
+ 'owner_id' => $this->userSession->getId(),
+ );
+
+ return $this->taskModification->update($values);
+ }
+
+ /**
+ * Check if the event data meet the action condition
+ *
+ * @access public
+ * @param array $data Event data dictionary
+ * @return bool
+ */
+ public function hasRequiredCondition(array $data)
+ {
+ return $data['column_id'] == $this->getParam('column_id');
+ }
+}
diff --git a/app/Action/TaskAssignSpecificUser.php b/app/Action/TaskAssignSpecificUser.php
index dfcb281b..2dc3e966 100644
--- a/app/Action/TaskAssignSpecificUser.php
+++ b/app/Action/TaskAssignSpecificUser.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskAssignSpecificUser extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Assign the task to a specific user');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
diff --git a/app/Action/TaskAssignUser.php b/app/Action/TaskAssignUser.php
index a5821729..bb3a83c2 100644
--- a/app/Action/TaskAssignUser.php
+++ b/app/Action/TaskAssignUser.php
@@ -14,6 +14,17 @@ use Kanboard\Integration\BitbucketWebhook;
class TaskAssignUser extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Change the assignee based on an external username');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
@@ -78,6 +89,6 @@ class TaskAssignUser extends Base
*/
public function hasRequiredCondition(array $data)
{
- return true;
+ return $this->projectPermission->isAssignable($this->getProjectId(), $data['owner_id']);
}
}
diff --git a/app/Action/TaskClose.php b/app/Action/TaskClose.php
index d80bd023..a4b093a4 100644
--- a/app/Action/TaskClose.php
+++ b/app/Action/TaskClose.php
@@ -16,6 +16,17 @@ use Kanboard\Model\Task;
class TaskClose extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Close a task');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
@@ -24,7 +35,6 @@ class TaskClose extends Base
public function getCompatibleEvents()
{
return array(
- Task::EVENT_MOVE_COLUMN,
GithubWebhook::EVENT_COMMIT,
GithubWebhook::EVENT_ISSUE_CLOSED,
GitlabWebhook::EVENT_COMMIT,
@@ -42,17 +52,7 @@ class TaskClose extends Base
*/
public function getActionRequiredParameters()
{
- switch ($this->event_name) {
- case GithubWebhook::EVENT_COMMIT:
- case GithubWebhook::EVENT_ISSUE_CLOSED:
- case GitlabWebhook::EVENT_COMMIT:
- case GitlabWebhook::EVENT_ISSUE_CLOSED:
- case BitbucketWebhook::EVENT_COMMIT:
- case BitbucketWebhook::EVENT_ISSUE_CLOSED:
- return array();
- default:
- return array('column_id' => t('Column'));
- }
+ return array();
}
/**
@@ -63,17 +63,7 @@ class TaskClose extends Base
*/
public function getEventRequiredParameters()
{
- switch ($this->event_name) {
- case GithubWebhook::EVENT_COMMIT:
- case GithubWebhook::EVENT_ISSUE_CLOSED:
- case GitlabWebhook::EVENT_COMMIT:
- case GitlabWebhook::EVENT_ISSUE_CLOSED:
- case BitbucketWebhook::EVENT_COMMIT:
- case BitbucketWebhook::EVENT_ISSUE_CLOSED:
- return array('task_id');
- default:
- return array('task_id', 'column_id');
- }
+ return array('task_id');
}
/**
@@ -97,16 +87,6 @@ class TaskClose extends Base
*/
public function hasRequiredCondition(array $data)
{
- switch ($this->event_name) {
- case GithubWebhook::EVENT_COMMIT:
- case GithubWebhook::EVENT_ISSUE_CLOSED:
- case GitlabWebhook::EVENT_COMMIT:
- case GitlabWebhook::EVENT_ISSUE_CLOSED:
- case BitbucketWebhook::EVENT_COMMIT:
- case BitbucketWebhook::EVENT_ISSUE_CLOSED:
- return true;
- default:
- return $data['column_id'] == $this->getParam('column_id');
- }
+ return true;
}
}
diff --git a/app/Action/TaskCloseColumn.php b/app/Action/TaskCloseColumn.php
new file mode 100644
index 00000000..09af3b96
--- /dev/null
+++ b/app/Action/TaskCloseColumn.php
@@ -0,0 +1,84 @@
+<?php
+
+namespace Kanboard\Action;
+
+use Kanboard\Model\Task;
+
+/**
+ * Close automatically a task in a specific column
+ *
+ * @package action
+ * @author Frederic Guillot
+ */
+class TaskCloseColumn extends Base
+{
+ /**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Close a task in a specific column');
+ }
+
+ /**
+ * Get the list of compatible events
+ *
+ * @access public
+ * @return array
+ */
+ public function getCompatibleEvents()
+ {
+ return array(
+ Task::EVENT_MOVE_COLUMN,
+ );
+ }
+
+ /**
+ * Get the required parameter for the action (defined by the user)
+ *
+ * @access public
+ * @return array
+ */
+ public function getActionRequiredParameters()
+ {
+ return array('column_id' => t('Column'));
+ }
+
+ /**
+ * Get the required parameter for the event
+ *
+ * @access public
+ * @return string[]
+ */
+ public function getEventRequiredParameters()
+ {
+ return array('task_id', 'column_id');
+ }
+
+ /**
+ * Execute the action (close the task)
+ *
+ * @access public
+ * @param array $data Event data dictionary
+ * @return bool True if the action was executed or false when not executed
+ */
+ public function doAction(array $data)
+ {
+ return $this->taskStatus->close($data['task_id']);
+ }
+
+ /**
+ * Check if the event data meet the action condition
+ *
+ * @access public
+ * @param array $data Event data dictionary
+ * @return bool
+ */
+ public function hasRequiredCondition(array $data)
+ {
+ return $data['column_id'] == $this->getParam('column_id');
+ }
+}
diff --git a/app/Action/TaskCreation.php b/app/Action/TaskCreation.php
index af1403f0..23ff4592 100644
--- a/app/Action/TaskCreation.php
+++ b/app/Action/TaskCreation.php
@@ -15,6 +15,17 @@ use Kanboard\Integration\BitbucketWebhook;
class TaskCreation extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Create a task from an external provider');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
diff --git a/app/Action/TaskDuplicateAnotherProject.php b/app/Action/TaskDuplicateAnotherProject.php
index 1f6684dd..5bcdce08 100644
--- a/app/Action/TaskDuplicateAnotherProject.php
+++ b/app/Action/TaskDuplicateAnotherProject.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskDuplicateAnotherProject extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Duplicate the task to another project');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
@@ -51,7 +62,6 @@ class TaskDuplicateAnotherProject extends Base
return array(
'task_id',
'column_id',
- 'project_id',
);
}
@@ -65,7 +75,6 @@ class TaskDuplicateAnotherProject extends Base
public function doAction(array $data)
{
$destination_column_id = $this->board->getFirstColumn($this->getParam('project_id'));
-
return (bool) $this->taskDuplication->duplicateToProject($data['task_id'], $this->getParam('project_id'), null, $destination_column_id);
}
diff --git a/app/Action/TaskEmail.php b/app/Action/TaskEmail.php
index 7fb76c4c..4e0e06a6 100644
--- a/app/Action/TaskEmail.php
+++ b/app/Action/TaskEmail.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskEmail extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Send a task by email to someone');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
diff --git a/app/Action/TaskMoveAnotherProject.php b/app/Action/TaskMoveAnotherProject.php
index 476e2036..fdff0d8c 100644
--- a/app/Action/TaskMoveAnotherProject.php
+++ b/app/Action/TaskMoveAnotherProject.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskMoveAnotherProject extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Move the task to another project');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
diff --git a/app/Action/TaskMoveColumnAssigned.php b/app/Action/TaskMoveColumnAssigned.php
index 16622ee4..1b23a591 100644
--- a/app/Action/TaskMoveColumnAssigned.php
+++ b/app/Action/TaskMoveColumnAssigned.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskMoveColumnAssigned extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Move the task to another column when assigned to a user');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
@@ -51,7 +62,6 @@ class TaskMoveColumnAssigned extends Base
return array(
'task_id',
'column_id',
- 'project_id',
'owner_id'
);
}
diff --git a/app/Action/TaskMoveColumnCategoryChange.php b/app/Action/TaskMoveColumnCategoryChange.php
index 1e12be4a..0f591eda 100644
--- a/app/Action/TaskMoveColumnCategoryChange.php
+++ b/app/Action/TaskMoveColumnCategoryChange.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskMoveColumnCategoryChange extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Move the task to another column when the category is changed');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
@@ -50,7 +61,6 @@ class TaskMoveColumnCategoryChange extends Base
return array(
'task_id',
'column_id',
- 'project_id',
'category_id',
);
}
@@ -71,7 +81,8 @@ class TaskMoveColumnCategoryChange extends Base
$data['task_id'],
$this->getParam('dest_column_id'),
$original_task['position'],
- $original_task['swimlane_id']
+ $original_task['swimlane_id'],
+ false
);
}
diff --git a/app/Action/TaskMoveColumnUnAssigned.php b/app/Action/TaskMoveColumnUnAssigned.php
index 617c75a8..99ef9351 100644
--- a/app/Action/TaskMoveColumnUnAssigned.php
+++ b/app/Action/TaskMoveColumnUnAssigned.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskMoveColumnUnAssigned extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Move the task to another column when assignee is cleared');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
@@ -51,7 +62,6 @@ class TaskMoveColumnUnAssigned extends Base
return array(
'task_id',
'column_id',
- 'project_id',
'owner_id'
);
}
diff --git a/app/Action/TaskOpen.php b/app/Action/TaskOpen.php
index 2e84c695..a1ab622c 100644
--- a/app/Action/TaskOpen.php
+++ b/app/Action/TaskOpen.php
@@ -15,6 +15,17 @@ use Kanboard\Integration\BitbucketWebhook;
class TaskOpen extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Open a task');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
diff --git a/app/Action/TaskUpdateStartDate.php b/app/Action/TaskUpdateStartDate.php
index 4cd548af..011a5baf 100644
--- a/app/Action/TaskUpdateStartDate.php
+++ b/app/Action/TaskUpdateStartDate.php
@@ -13,6 +13,17 @@ use Kanboard\Model\Task;
class TaskUpdateStartDate extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Automatically update the start date');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
diff --git a/app/Action/Base.php b/app/Action/Base.php
index 81e2ccc6..febd6cfc 100644
--- a/app/Action/Base.php
+++ b/app/Action/Base.php
@@ -3,7 +3,6 @@
namespace Kanboard\Action;
use Kanboard\Event\GenericEvent;
-use Pimple\Container;
/**
* Base class for automatic actions
@@ -14,6 +13,14 @@ use Pimple\Container;
abstract class Base extends \Kanboard\Core\Base
{
/**
+ * Extended events
+ *
+ * @access private
+ * @var array
+ */
+ private $compatibleEvents = array();
+
+ /**
* Flag for called listener
*
* @access private
@@ -27,7 +34,7 @@ abstract class Base extends \Kanboard\Core\Base
* @access private
* @var integer
*/
- private $project_id = 0;
+ private $projectId = 0;
/**
* User parameters
@@ -38,20 +45,25 @@ abstract class Base extends \Kanboard\Core\Base
private $params = array();
/**
- * Attached event name
+ * Get automatic action name
*
- * @access protected
- * @var string
+ * @final
+ * @access public
+ * @return string
*/
- protected $event_name = '';
+ final public function getName()
+ {
+ return '\\'.get_called_class();
+ }
/**
- * Container instance
+ * Get automatic action description
*
- * @access protected
- * @var \Pimple\Container
+ * @abstract
+ * @access public
+ * @return string
*/
- protected $container;
+ abstract public function getDescription();
/**
* Execute the action
@@ -100,30 +112,26 @@ abstract class Base extends \Kanboard\Core\Base
abstract public function hasRequiredCondition(array $data);
/**
- * Constructor
+ * Return class information
*
* @access public
- * @param \Pimple\Container $container Container
- * @param integer $project_id Project id
- * @param string $event_name Attached event name
+ * @return string
*/
- public function __construct(Container $container, $project_id, $event_name)
+ public function __toString()
{
- $this->container = $container;
- $this->project_id = $project_id;
- $this->event_name = $event_name;
- $this->called = false;
+ return $this->getName();
}
/**
- * Return class information
+ * Set project id
*
* @access public
- * @return string
+ * @return Base
*/
- public function __toString()
+ public function setProjectId($project_id)
{
- return get_called_class();
+ $this->projectId = $project_id;
+ return $this;
}
/**
@@ -134,7 +142,7 @@ abstract class Base extends \Kanboard\Core\Base
*/
public function getProjectId()
{
- return $this->project_id;
+ return $this->projectId;
}
/**
@@ -143,10 +151,12 @@ abstract class Base extends \Kanboard\Core\Base
* @access public
* @param string $name Parameter name
* @param mixed $value Value
+ * @param Base
*/
public function setParam($name, $value)
{
$this->params[$name] = $value;
+ return $this;
}
/**
@@ -154,24 +164,25 @@ abstract class Base extends \Kanboard\Core\Base
*
* @access public
* @param string $name Parameter name
- * @param mixed $default_value Default value
+ * @param mixed $default Default value
* @return mixed
*/
- public function getParam($name, $default_value = null)
+ public function getParam($name, $default = null)
{
- return isset($this->params[$name]) ? $this->params[$name] : $default_value;
+ return isset($this->params[$name]) ? $this->params[$name] : $default;
}
/**
* Check if an action is executable (right project and required parameters)
*
* @access public
* @param array $data Event data dictionary
* @return bool True if the action is executable
*/
- public function isExecutable(array $data)
+ public function isExecutable(array $data, $eventName)
{
- return $this->hasCompatibleEvent() &&
+ return $this->hasCompatibleEvent($eventName) &&
$this->hasRequiredProject($data) &&
$this->hasRequiredParameters($data) &&
$this->hasRequiredCondition($data);
@@ -181,11 +192,12 @@ abstract class Base extends \Kanboard\Core\Base
* Check if the event is compatible with the action
*
* @access public
+ * @param string $eventName
* @return bool
*/
- public function hasCompatibleEvent()
+ public function hasCompatibleEvent($eventName)
{
- return in_array($this->event_name, $this->getCompatibleEvents());
+ return in_array($eventName, $this->getEvents());
}
/**
@@ -197,7 +209,7 @@ abstract class Base extends \Kanboard\Core\Base
*/
public function hasRequiredProject(array $data)
{
- return isset($data['project_id']) && $data['project_id'] == $this->project_id;
+ return isset($data['project_id']) && $data['project_id'] == $this->getProjectId();
}
/**
@@ -222,10 +234,11 @@ abstract class Base extends \Kanboard\Core\Base
* Execute the action
*
* @access public
- * @param \Event\GenericEvent $event Event data dictionary
- * @return bool True if the action was executed or false when not executed
+ * @param \Kanboard\Event\GenericEvent $event
+ * @param string $eventName
+ * @return bool
*/
- public function execute(GenericEvent $event)
+ public function execute(GenericEvent $event, $eventName)
{
// Avoid infinite loop, a listener instance can be called only one time
if ($this->called) {
@@ -235,15 +248,38 @@ abstract class Base extends \Kanboard\Core\Base
$data = $event->getAll();
$result = false;
- if ($this->isExecutable($data)) {
+ if ($this->isExecutable($data, $eventName)) {
$this->called = true;
$result = $this->doAction($data);
}
- if (DEBUG) {
- $this->logger->debug(get_called_class().' => '.($result ? 'true' : 'false'));
- }
+ $this->logger->debug('AutomaticAction '.$this->getName().' => '.($result ? 'true' : 'false'));
return $result;
}
+
+ /**
+ * Register a new event for the automatic action
+ *
+ * @access public
+ * @param string $event
+ * @param string $description
+ */
+ public function addEvent($event, $description)
+ {
+ $this->eventManager->register($event, $description);
+ $this->compatibleEvents[] = $event;
+ return $this;
+ }
+
+ /**
+ * Get all compatible events of an automatic action
+ *
+ * @access public
+ * @return array
+ */
+ public function getEvents()
+ {
+ return array_unique(array_merge($this->getCompatibleEvents(), $this->compatibleEvents));
+ }
}
@@ -154,24 +164,25 @@ abstract class Base extends \Kanboard\Core\Base
*
* @access public
- * @param array $data Event data dictionary
- * @return bool True if the action is executable
+ * @param array $data
+ * @param string $eventName
+ * @return bool
*/
diff --git a/app/Action/TaskLogMoveAnotherColumn.php b/app/Action/CommentCreationMoveTaskColumn.php
index a699c4ab..4473cf91 100644
--- a/app/Action/TaskLogMoveAnotherColumn.php
+++ b/app/Action/CommentCreationMoveTaskColumn.php
@@ -5,14 +5,25 @@ namespace Kanboard\Action;
use Kanboard\Model\Task;
/**
* Add a log of the triggering event to the task description.
*
* @package action
* @author Oren Ben-Kiki
*/
-class TaskLogMoveAnotherColumn extends Base
+class CommentCreationMoveTaskColumn extends Base
{
/**
+ * Get automatic action description
+ *
+ * @access public
+ * @return string
+ */
+ public function getDescription()
+ {
+ return t('Add a comment log when moving the task between columns');
+ }
+
+ /**
* Get the list of compatible events
*
* @access public
@@ -5,14 +5,25 @@ namespace Kanboard\Action;
use Kanboard\Model\Task;
/**
- * Add a log of the triggering event to the task description.
+ * Add a comment of the triggering event to the task description.
*
* @package action